package com.link.core.util;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.serializer.SerializerFeature;
import com.link.core.util.redisclient.LinkRedisClient;
import java.util.ArrayList;
import java.util.List;

public class RedisDataReportUtil {
   public static final String USER_TYPE = "USER";
   public static final String CORP_TYPE = "CORP";
   public static final String REPORT_TIME_FIELD = "reportCacheTime";

   public static String getReportStringDataFromRedis(String key) {
      LinkRedisClient jedis = null;

      String var4;
      try {
         jedis = RedisUtil.getJedis();
         String result = jedis.get(key);
         return result;
      } catch (Exception var8) {
         var4 = "";
      } finally {
         RedisUtil.returnResource(jedis);
      }

      return var4;
   }

   public static List getReportListDataFromRedis(String key, Class clazz) {
      List result = new ArrayList();
      LinkRedisClient jedis = null;

      ArrayList var6;
      try {
         jedis = RedisUtil.getJedis();
         String str = jedis.get(key);
         List result = JSONArray.parseArray(str, clazz);
         return result;
      } catch (Exception var10) {
         var6 = result;
      } finally {
         RedisUtil.returnResource(jedis);
      }

      return var6;
   }

   public static JSONArray getReportJsonDataFromRedis(String key) {
      JSONArray jsonArray = new JSONArray();
      LinkRedisClient jedis = null;

      JSONArray var5;
      try {
         jedis = RedisUtil.getJedis();
         String str = jedis.get(key);
         if (!StringUtils.isBlank(str)) {
            jsonArray = JSONArray.parseArray(str);
         }

         return jsonArray;
      } catch (Exception var9) {
         var5 = jsonArray;
      } finally {
         RedisUtil.returnResource(jedis);
      }

      return var5;
   }

   public static void addReportStringDataToRedis(String key, String value, int seconds) {
      LinkRedisClient jedis = null;

      try {
         jedis = RedisUtil.getJedis();
         jedis.set(key, value);
         jedis.expire(key, seconds);
      } finally {
         RedisUtil.returnResource(jedis);
      }

   }

   public static void addReportListDataToRedis(String key, List list, int seconds) {
      LinkRedisClient jedis = null;
      JSONArray jsonArray = new JSONArray(list);
      String value = JSONArray.toJSONString(jsonArray);

      try {
         jedis = RedisUtil.getJedis();
         jedis.set(key, value);
         jedis.expire(key, seconds);
      } finally {
         RedisUtil.returnResource(jedis);
      }

   }

   public static void addReportJsonDataToRedis(String key, JSONArray jsonArray, int seconds) {
      LinkRedisClient jedis = null;
      String value = JSONArray.toJSONString(jsonArray);

      try {
         jedis = RedisUtil.getJedis();
         jedis.set(key, value);
         jedis.expire(key, seconds);
      } finally {
         RedisUtil.returnResource(jedis);
      }

   }

   public static String generateRedisKey(String type, String id, String methodName) {
      String key = type + "_" + id + "_" + methodName;
      return key;
   }

   public static int getCfgCorpReportTimeProperty(String hkey, String field) {
      int seconds = -1;
      LinkRedisClient jedis = null;

      try {
         jedis = RedisUtil.getJedis();
         if (!StringUtils.isBlank(jedis.hget(hkey, field))) {
            String str = jedis.hget(hkey, field);
            if (str.matches("[0-9]{1,}")) {
               seconds = Integer.parseInt(str);
            }
         }
      } finally {
         RedisUtil.returnResource(jedis);
      }

      return seconds;
   }

   public static JSONObject getRedisStringValue2FastJson(String key) {
      JSONObject jsonObject = new JSONObject();
      LinkRedisClient jedis = null;

      try {
         jedis = RedisUtil.getJedis();
         String value = jedis.get(key);
         RedisUtil.returnResource(jedis);
         if (!StringUtils.isBlank(value)) {
            jsonObject = JSONObject.parseObject(value);
         }
      } finally {
         RedisUtil.returnResource(jedis);
      }

      return jsonObject;
   }

   public static void addRedisStringData(Object object, String key, int seconds, boolean writeNullValue) {
      String value;
      if (writeNullValue) {
         value = JSONObject.toJSONString(object, new SerializerFeature[]{SerializerFeature.WriteMapNullValue});
      } else {
         value = JSONObject.toJSONString(object);
      }

      LinkRedisClient jedis = null;

      try {
         jedis = RedisUtil.getJedis();
         jedis.set(key, value);
         jedis.expire(key, seconds);
      } finally {
         RedisUtil.returnResource(jedis);
      }

   }
}
